==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/APMSCENARIOPROJECTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour APMSCENARIOPROJECTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="APMSCENARIOPROJECTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APMSCENARIOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROJECTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APMSCENARIOPROJECTID_Type", propOrder = {
    "apmscenarioid",
    "projectid"
})
public class APMSCENARIOPROJECTID_Type {

    @XmlElement(name = "APMSCENARIOID", required = true)
    protected STANDARDENTITYID_Type apmscenarioid;
    @XmlElement(name = "PROJECTID", required = true)
    protected PROJECTID_Type projectid;

    /**
     * Obtient la valeur de la propriété apmscenarioid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPMSCENARIOID() {
        return apmscenarioid;
    }

    /**
     * Définit la valeur de la propriété apmscenarioid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPMSCENARIOID(STANDARDENTITYID_Type value) {
        this.apmscenarioid = value;
    }

    /**
     * Obtient la valeur de la propriété projectid.
     * 
     * @return
     *     possible object is
     *     {@link PROJECTID_Type }
     *     
     */
    public PROJECTID_Type getPROJECTID() {
        return projectid;
    }

    /**
     * Définit la valeur de la propriété projectid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROJECTID_Type }
     *     
     */
    public void setPROJECTID(PROJECTID_Type value) {
        this.projectid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/APMSCENARIOPROJECTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APMSCENARIOPROJECTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APMSCENARIOPROJECTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APMSCENARIOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROJECTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APMSCENARIOPROJECTID_Type", propOrder = {
    "apmscenarioid",
    "projectid"
})
public class APMSCENARIOPROJECTID_Type {

    @XmlElement(name = "APMSCENARIOID", required = true)
    protected STANDARDENTITYID_Type apmscenarioid;
    @XmlElement(name = "PROJECTID", required = true)
    protected PROJECTID_Type projectid;

    /**
     * Gets the value of the apmscenarioid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPMSCENARIOID() {
        return apmscenarioid;
    }

    /**
     * Sets the value of the apmscenarioid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPMSCENARIOID(STANDARDENTITYID_Type value) {
        this.apmscenarioid = value;
    }

    /**
     * Gets the value of the projectid property.
     * 
     * @return
     *     possible object is
     *     {@link PROJECTID_Type }
     *     
     */
    public PROJECTID_Type getPROJECTID() {
        return projectid;
    }

    /**
     * Sets the value of the projectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROJECTID_Type }
     *     
     */
    public void setPROJECTID(PROJECTID_Type value) {
        this.projectid = value;
    }

}
